import { HttpClient } from '@angular/common/http';
import { BaseService as __BaseService } from '../base-service';
import { ApiConfiguration as __Configuration } from '../api-configuration';
import { StrictHttpResponse as __StrictHttpResponse } from '../strict-http-response';
import { Observable as __Observable } from 'rxjs';
import { OrderTOResponse } from '../models/order-toresponse';
import { CloseOrderForm } from '../models/close-order-form';
import { OrderTOList } from '../models/order-tolist';
import { CloseOrderOnMarketForm } from '../models/close-order-on-market-form';
import { OrderPageTOResponse } from '../models/order-page-toresponse';
import { DecentCoinOverviewTOResponse } from '../models/decent-coin-overview-toresponse';
import { OrderDetailsTOResponse } from '../models/order-details-toresponse';
import { OrderTOListResponse } from '../models/order-tolist-response';
import { OpenOrderForm } from '../models/open-order-form';
import { OrderWithMoneyResultTOList } from '../models/order-with-money-result-tolist';
/**
 * Order Controller
 */
declare class OrderControllerService extends __BaseService {
    static readonly closeUsingPOSTPath = "/api/v1/order/close";
    static readonly closeAllOrdersUsingPOSTPath = "/api/v1/order/close-all";
    static readonly closeOnMarketUsingPOSTPath = "/api/v1/order/close-by-market-id";
    static readonly getDwrldHistoryUsingGETPath = "/api/v1/order/dcw/list";
    static readonly getDecentCoinOverviewUsingGETPath = "/api/v1/order/dcw/overview";
    static readonly orderDetailsUsingGETPath = "/api/v1/order/details/{orderId}";
    static readonly historyUsingGET1Path = "/api/v1/order/history";
    static readonly listUsingGET15Path = "/api/v1/order/list";
    static readonly historyNftUsingGETPath = "/api/v1/order/nft/history";
    static readonly openUsingPOSTPath = "/api/v1/order/open";
    static readonly getStreetsSalesUsingGETPath = "/api/v1/order/streets/latest-sell";
    constructor(config: __Configuration, http: HttpClient);
    /**
     * close
     * @param form form
     * @return OK
     */
    closeUsingPOSTResponse(form: CloseOrderForm): __Observable<__StrictHttpResponse<OrderTOResponse>>;
    /**
     * close
     * @param form form
     * @return OK
     */
    closeUsingPOST(form: CloseOrderForm): __Observable<OrderTOResponse>;
    /**
     * Close limit 1000 orders at once
     * @param params The `OrderControllerService.CloseAllOrdersUsingPOSTParams` containing the following parameters:
     *
     * - `side`: side
     *
     * - `markets`: markets
     *
     * - `isNotNft`: isNotNft
     *
     * - `isNft`: isNft
     *
     * @return OK
     */
    closeAllOrdersUsingPOSTResponse(params: OrderControllerService.CloseAllOrdersUsingPOSTParams): __Observable<__StrictHttpResponse<OrderTOList>>;
    /**
     * Close limit 1000 orders at once
     * @param params The `OrderControllerService.CloseAllOrdersUsingPOSTParams` containing the following parameters:
     *
     * - `side`: side
     *
     * - `markets`: markets
     *
     * - `isNotNft`: isNotNft
     *
     * - `isNft`: isNft
     *
     * @return OK
     */
    closeAllOrdersUsingPOST(params: OrderControllerService.CloseAllOrdersUsingPOSTParams): __Observable<OrderTOList>;
    /**
     * Use to close SELL order for NFT by marketId
     * @param form form
     * @return OK
     */
    closeOnMarketUsingPOSTResponse(form: CloseOrderOnMarketForm): __Observable<__StrictHttpResponse<OrderTOResponse>>;
    /**
     * Use to close SELL order for NFT by marketId
     * @param form form
     * @return OK
     */
    closeOnMarketUsingPOST(form: CloseOrderOnMarketForm): __Observable<OrderTOResponse>;
    /**
     * getDwrldHistory
     * @param params The `OrderControllerService.GetDwrldHistoryUsingGETParams` containing the following parameters:
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * @return OK
     */
    getDwrldHistoryUsingGETResponse(params: OrderControllerService.GetDwrldHistoryUsingGETParams): __Observable<__StrictHttpResponse<OrderPageTOResponse>>;
    /**
     * getDwrldHistory
     * @param params The `OrderControllerService.GetDwrldHistoryUsingGETParams` containing the following parameters:
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * @return OK
     */
    getDwrldHistoryUsingGET(params: OrderControllerService.GetDwrldHistoryUsingGETParams): __Observable<OrderPageTOResponse>;
    /**
     * getDecentCoinOverview
     * @return OK
     */
    getDecentCoinOverviewUsingGETResponse(): __Observable<__StrictHttpResponse<DecentCoinOverviewTOResponse>>;
    /**
     * getDecentCoinOverview
     * @return OK
     */
    getDecentCoinOverviewUsingGET(): __Observable<DecentCoinOverviewTOResponse>;
    /**
     * Order details for open or history
     * @param orderId orderId
     * @return OK
     */
    orderDetailsUsingGETResponse(orderId: number): __Observable<__StrictHttpResponse<OrderDetailsTOResponse>>;
    /**
     * Order details for open or history
     * @param orderId orderId
     * @return OK
     */
    orderDetailsUsingGET(orderId: number): __Observable<OrderDetailsTOResponse>;
    /**
     * history
     * @param params The `OrderControllerService.HistoryUsingGET1Params` containing the following parameters:
     *
     * - `street`: street
     *
     * - `state`: state
     *
     * - `sort`: sort
     *
     * - `side`: side
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * - `orderType`: orderType
     *
     * - `markets`: markets
     *
     * - `isNotNft`: isNotNft
     *
     * - `isNft`: isNft
     *
     * - `forAllUsers`: forAllUsers
     *
     * - `dateTo`: dateTo
     *
     * - `dateFrom`: dateFrom
     *
     * - `country`: country
     *
     * - `closeReason`: closeReason
     *
     * - `city`: city
     *
     * @return OK
     */
    historyUsingGET1Response(params: OrderControllerService.HistoryUsingGET1Params): __Observable<__StrictHttpResponse<OrderTOListResponse>>;
    /**
     * history
     * @param params The `OrderControllerService.HistoryUsingGET1Params` containing the following parameters:
     *
     * - `street`: street
     *
     * - `state`: state
     *
     * - `sort`: sort
     *
     * - `side`: side
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * - `orderType`: orderType
     *
     * - `markets`: markets
     *
     * - `isNotNft`: isNotNft
     *
     * - `isNft`: isNft
     *
     * - `forAllUsers`: forAllUsers
     *
     * - `dateTo`: dateTo
     *
     * - `dateFrom`: dateFrom
     *
     * - `country`: country
     *
     * - `closeReason`: closeReason
     *
     * - `city`: city
     *
     * @return OK
     */
    historyUsingGET1(params: OrderControllerService.HistoryUsingGET1Params): __Observable<OrderTOListResponse>;
    /**
     * list
     * @param params The `OrderControllerService.ListUsingGET15Params` containing the following parameters:
     *
     * - `street`: street
     *
     * - `state`: state
     *
     * - `sort`: sort
     *
     * - `side`: side
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * - `orderType`: orderType
     *
     * - `nftWalletId`: nftWalletId
     *
     * - `markets`: markets
     *
     * - `isNotNft`: isNotNft
     *
     * - `isNft`: isNft
     *
     * - `dateTo`: dateTo
     *
     * - `dateFrom`: dateFrom
     *
     * - `country`: country
     *
     * - `closeReason`: closeReason
     *
     * - `city`: city
     *
     * @return OK
     */
    listUsingGET15Response(params: OrderControllerService.ListUsingGET15Params): __Observable<__StrictHttpResponse<OrderTOListResponse>>;
    /**
     * list
     * @param params The `OrderControllerService.ListUsingGET15Params` containing the following parameters:
     *
     * - `street`: street
     *
     * - `state`: state
     *
     * - `sort`: sort
     *
     * - `side`: side
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * - `orderType`: orderType
     *
     * - `nftWalletId`: nftWalletId
     *
     * - `markets`: markets
     *
     * - `isNotNft`: isNotNft
     *
     * - `isNft`: isNft
     *
     * - `dateTo`: dateTo
     *
     * - `dateFrom`: dateFrom
     *
     * - `country`: country
     *
     * - `closeReason`: closeReason
     *
     * - `city`: city
     *
     * @return OK
     */
    listUsingGET15(params: OrderControllerService.ListUsingGET15Params): __Observable<OrderTOListResponse>;
    /**
     * NFT market history
     * @param params The `OrderControllerService.HistoryNftUsingGETParams` containing the following parameters:
     *
     * - `id`: id
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * @return OK
     */
    historyNftUsingGETResponse(params: OrderControllerService.HistoryNftUsingGETParams): __Observable<__StrictHttpResponse<OrderTOListResponse>>;
    /**
     * NFT market history
     * @param params The `OrderControllerService.HistoryNftUsingGETParams` containing the following parameters:
     *
     * - `id`: id
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * @return OK
     */
    historyNftUsingGET(params: OrderControllerService.HistoryNftUsingGETParams): __Observable<OrderTOListResponse>;
    /**
     * open
     * @param form form
     * @return OK
     */
    openUsingPOSTResponse(form: OpenOrderForm): __Observable<__StrictHttpResponse<OrderTOResponse>>;
    /**
     * open
     * @param form form
     * @return OK
     */
    openUsingPOST(form: OpenOrderForm): __Observable<OrderTOResponse>;
    /**
     * getStreetsSales
     * @param params The `OrderControllerService.GetStreetsSalesUsingGETParams` containing the following parameters:
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * @return OK
     */
    getStreetsSalesUsingGETResponse(params: OrderControllerService.GetStreetsSalesUsingGETParams): __Observable<__StrictHttpResponse<OrderWithMoneyResultTOList>>;
    /**
     * getStreetsSales
     * @param params The `OrderControllerService.GetStreetsSalesUsingGETParams` containing the following parameters:
     *
     * - `pageSize`: pageSize
     *
     * - `pageNumber`: pageNumber
     *
     * @return OK
     */
    getStreetsSalesUsingGET(params: OrderControllerService.GetStreetsSalesUsingGETParams): __Observable<OrderWithMoneyResultTOList>;
}
declare module OrderControllerService {
    /**
     * Parameters for closeAllOrdersUsingPOST
     */
    interface CloseAllOrdersUsingPOSTParams {
        /**
         * side
         */
        side?: 'BUY' | 'SELL' | 'UNKNOWN_SIDE' | 'UNRECOGNIZED';
        /**
         * markets
         */
        markets?: Array<number>;
        /**
         * isNotNft
         */
        isNotNft?: boolean;
        /**
         * isNft
         */
        isNft?: boolean;
    }
    /**
     * Parameters for getDwrldHistoryUsingGET
     */
    interface GetDwrldHistoryUsingGETParams {
        /**
         * pageSize
         */
        pageSize?: number;
        /**
         * pageNumber
         */
        pageNumber?: number;
    }
    /**
     * Parameters for historyUsingGET1
     */
    interface HistoryUsingGET1Params {
        /**
         * street
         */
        street?: string;
        /**
         * state
         */
        state?: 'STATE_ACTIVE' | 'STATE_COMPLETED' | 'STATE_PENDING' | 'UNKNOWN_STATE' | 'UNRECOGNIZED';
        /**
         * sort
         */
        sort?: string;
        /**
         * side
         */
        side?: 'BUY' | 'SELL' | 'UNKNOWN_SIDE' | 'UNRECOGNIZED';
        /**
         * pageSize
         */
        pageSize?: number;
        /**
         * pageNumber
         */
        pageNumber?: number;
        /**
         * orderType
         */
        orderType?: 'LIMIT' | 'MARKET' | 'MARKET_MARGIN_CALL' | 'UNKNOWN_ORDER_TYPE' | 'UNRECOGNIZED';
        /**
         * markets
         */
        markets?: Array<number>;
        /**
         * isNotNft
         */
        isNotNft?: boolean;
        /**
         * isNft
         */
        isNft?: boolean;
        /**
         * forAllUsers
         */
        forAllUsers?: boolean;
        /**
         * dateTo
         */
        dateTo?: string;
        /**
         * dateFrom
         */
        dateFrom?: string;
        /**
         * country
         */
        country?: string;
        /**
         * closeReason
         */
        closeReason?: 'CANCELLED_BY_ADMIN' | 'CANCELLED_BY_OWNER' | 'COMPLETED' | 'EMPTY_AMOUNT' | 'ERROR' | 'MARKET_DISABLED' | 'MARKET_ORDER_NOT_FILLED' | 'OPEN' | 'PARTIALLY_FILLED' | 'PENDING_CANCEL' | 'PENDING_MARKET_DISABLED' | 'TIME_EXPIRED' | 'TOO_LOW_AMOUNT' | 'TOO_LOW_MATCH' | 'UNKNOWN_CLOSE_REASON' | 'UNRECOGNIZED';
        /**
         * city
         */
        city?: string;
    }
    /**
     * Parameters for listUsingGET15
     */
    interface ListUsingGET15Params {
        /**
         * street
         */
        street?: string;
        /**
         * state
         */
        state?: 'STATE_ACTIVE' | 'STATE_COMPLETED' | 'STATE_PENDING' | 'UNKNOWN_STATE' | 'UNRECOGNIZED';
        /**
         * sort
         */
        sort?: string;
        /**
         * side
         */
        side?: 'BUY' | 'SELL' | 'UNKNOWN_SIDE' | 'UNRECOGNIZED';
        /**
         * pageSize
         */
        pageSize?: number;
        /**
         * pageNumber
         */
        pageNumber?: number;
        /**
         * orderType
         */
        orderType?: 'LIMIT' | 'MARKET' | 'MARKET_MARGIN_CALL' | 'UNKNOWN_ORDER_TYPE' | 'UNRECOGNIZED';
        /**
         * nftWalletId
         */
        nftWalletId?: number;
        /**
         * markets
         */
        markets?: Array<number>;
        /**
         * isNotNft
         */
        isNotNft?: boolean;
        /**
         * isNft
         */
        isNft?: boolean;
        /**
         * dateTo
         */
        dateTo?: string;
        /**
         * dateFrom
         */
        dateFrom?: string;
        /**
         * country
         */
        country?: string;
        /**
         * closeReason
         */
        closeReason?: 'CANCELLED_BY_ADMIN' | 'CANCELLED_BY_OWNER' | 'COMPLETED' | 'EMPTY_AMOUNT' | 'ERROR' | 'MARKET_DISABLED' | 'MARKET_ORDER_NOT_FILLED' | 'OPEN' | 'PARTIALLY_FILLED' | 'PENDING_CANCEL' | 'PENDING_MARKET_DISABLED' | 'TIME_EXPIRED' | 'TOO_LOW_AMOUNT' | 'TOO_LOW_MATCH' | 'UNKNOWN_CLOSE_REASON' | 'UNRECOGNIZED';
        /**
         * city
         */
        city?: string;
    }
    /**
     * Parameters for historyNftUsingGET
     */
    interface HistoryNftUsingGETParams {
        /**
         * id
         */
        id: number;
        /**
         * pageSize
         */
        pageSize?: number;
        /**
         * pageNumber
         */
        pageNumber?: number;
    }
    /**
     * Parameters for getStreetsSalesUsingGET
     */
    interface GetStreetsSalesUsingGETParams {
        /**
         * pageSize
         */
        pageSize?: number;
        /**
         * pageNumber
         */
        pageNumber?: number;
    }
}
export { OrderControllerService };
